%define anolis_release 2

Name:           malcontent
Version:        0.11.1
Release:        %{anolis_release}%{?dist}
Summary:        Parental controls implementation

License:        LGPLv2+
URL:            https://gitlab.freedesktop.org/pwithnall/malcontent/
Source0:        %{url}/-/archive/%{version}/%{name}-%{version}.tar.bz2

BuildRequires:  itstool
BuildRequires:  gettext
BuildRequires:  pam-devel
BuildRequires:  meson git gcc cmake
BuildRequires:  libappstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(flatpak)
BuildRequires:  pkgconfig(appstream)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(glib-testing-0)
BuildRequires:  pkgconfig(accountsservice)
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(gobject-introspection-1.0)

Requires: polkit

%description
The libmalcontent library provides a set of APIs that can be used by
applications to implement parental controls. These APIs can be used to
set up filters, restrictions, and other rules that limit access to
inappropriate content.

Malcontent supports a variety of filters, including URL filters, domain
filters, and content type filters. These filters can be used to block
access to specific websites or types of content, such as adult content,
gambling sites, or social media.

Malcontent also supports custom filter lists, which allow administrators or
parents to specify their own rules for filtering content. These lists can
be used to block access to specific websites or types of content that are
not covered by the built-in filters.

Malcontent supports blacklists and whitelists, which allow administrators or
parents to specify which websites or domains are allowed or blocked. Blacklists
are lists of websites or domains that are not allowed, while whitelists are
lists of websites or domains that are allowed.

Malcontent supports time-based restrictions, which allow administrators or
parents to limit access to certain types of content during specific times of
the day or week. For example, access to social media sites might be blocked
during school hours or after bedtime.

Malcontent integrates with popular web browsers and email clients, making it
easy to apply parental controls to these applications. It also provides a
command-line interface for more advanced users.

Overall, malcontent provides a powerful set of tools for implementing parental
controls on Linux-based systems. Its flexible and customizable filters,
blacklists, and whitelists, as well as its support for time-based restrictions,
make it a valuable tool for ensuring that children are protected from
inappropriate content online.

%package pam
Summary:        Parental Controls PAM Module

%description pam
This package contains a PAM module which prevents logins for users who have
exceeded their allowed computer time.

%package control
Summary:        Parental Controls UI
Requires:       %{name} = %{version}-%{release}

%description control
This package contains a user interface for querying and setting parental
controls for users.

%package libs
Summary:        Libraries for %{name}

%description libs
This package contains libmalcontent.

%package tools
Summary:        Parental Controls Tools
Requires:       %{name} = %{version}-%{release}

%description tools
This package contains tools for querying and updating the parental controls
settings for users.

%package ui-libs
Summary:        Libraries for %{name}

%description ui-libs
This package contains libmalcontent-ui.

%package ui-devel
Summary:        Development files for libmalcontent-ui
Requires:       %{name}-ui-libs = %{version}-%{release}

%description ui-devel
This package contains the pkg-config file and development headers
for libmalcontent-ui.

%package devel
Summary:        Development files for %{name}
Requires:       %{name}-libs = %{version}-%{release}

%description devel
This package contains the pkg-config file and development headers
for %{name}.

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -p1 -S git

%build
%meson -Dui=enabled
%meson_build

%install
%meson_install
%find_lang %{name} --with-gnome

%generate_compatibility_deps

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/org.freedesktop.MalcontentControl.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.freedesktop.MalcontentControl.appdata.xml

%files -f %{name}.lang
%license COPYING COPYING-DOCS
%doc README.md
%{_datadir}/polkit-1/rules.d/com.endlessm.ParentalControls.rules
%{_datadir}/accountsservice/interfaces/
%{_datadir}/polkit-1/actions/*.policy
%{_datadir}/dbus-1/interfaces/

%files control
%license COPYING
%doc README.md
%{_bindir}/malcontent-control
%{abidir}/malcontent-control-option.list
%{_datadir}/icons/hicolor/symbolic/apps/org.freedesktop.MalcontentControl-symbolic.svg
%{_datadir}/applications/org.freedesktop.MalcontentControl.desktop
%{_datadir}/metainfo/org.freedesktop.MalcontentControl.appdata.xml
%{_datadir}/icons/hicolor/scalable/apps/org.freedesktop.MalcontentControl.svg

%files pam
%license COPYING COPYING-DOCS
%{abidir}/pam_malcontent.dump
%{_libdir}/security/pam_malcontent.so

%files ui-libs
%license COPYING COPYING-DOCS
%doc README.md
%{abidir}/libmalcontent-ui-1.dump
%dir %{_libdir}/girepository-1.0/
%{_libdir}/libmalcontent-ui-1.so.*
%{_libdir}/girepository-1.0/MalcontentUi-1.typelib

%files libs
%license COPYING COPYING-DOCS
%dir %{abidir}
%doc README.md
%dir %{_libdir}/girepository-1.0/
%{_libdir}/libmalcontent-0.so.*
%{abidir}/libmalcontent-0.dump
%{_libdir}/girepository-1.0/Malcontent-0.typelib

%files tools
%license COPYING COPYING-DOCS
%{_bindir}/malcontent-client
%{_mandir}/man8/malcontent-client.8.*

%files ui-devel
%license COPYING COPYING-DOCS
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/MalcontentUi-1.gir
%{_libdir}/libmalcontent-ui-1.so
%{_includedir}/malcontent-ui-1/
%{_libdir}/pkgconfig/malcontent-ui-1.pc

%files devel
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/Malcontent-0.gir
%{_includedir}/malcontent-0/
%{_libdir}/libmalcontent-0.so
%{_libdir}/pkgconfig/malcontent-0.pc

%files doc
%doc README.md
%doc HACKING.md
%doc NEWS

%changelog
* Sat Apr 15 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 0.11.1-2
- Optimize the spec

* Mon Mar 20 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 0.11.1-1
- update to version 0.11.1

* Mon May 09 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.10.4-1
- Init from upstream version  0.10.4
